Welcome to SMCPy’s documentation! — SMCPy 1.0 documentation

# Welcome to SMCPy’s documentation!

Contents:

- Introduction
- Example - Spring Mass System
  - Problem Specification
  - Step 1: Initialization; define the model and generate the data
  - Step 2: Perform Parameter Estimation using SMCPy
  - Step 3: Perform Parameter Estimation using MCMCPy
  - Comparing the Results
  - Running the SMCSampler in Parallel with mpi4py
- Source Code Documentation
  - SMC Module Documentation
  - Particle Module Documentation
  - MCMC Module Documentation

# Indices and tables

- Index
- Module Index
- Search Page